# Changelog

## v0.1.3 (01/09/2022)

### Fix

- Fixed typing problems, mypy connected.
- Fixed html documentation formatting.

### Tests

- Added more tests for dataclasses.

### Miscellaneous

- Added more validation to dataclasses.
- Improved documentation.
- Removed `get_mappings` method from the `cat2cat_mappings` dataclass.
- Removed not needed import calls.
- Created the project description and sidebar on pypi.
- Added pypi badge.

## v0.1.1 (30/08/2022)

- First test release of `cat2cat`!